@@ -39,15 +39,15 @@
 
 namespace Minuet
 {
-
 PluginController::PluginController(QObject *parent)
     : IPluginController(parent)
 {
 #if !defined(Q_OS_ANDROID)
     m_plugins = KPluginLoader::findPlugins(QStringLiteral("minuet"), [&](const KPluginMetaData &meta) {
         if (!meta.serviceTypes().contains(QStringLiteral("Minuet/Plugin"))) {
-            qDebug() << "Plugin" << meta.fileName() << "is installed into the minuet plugin directory, but does not have"
-                " \"Minuet/Plugin\" set as the service type. This plugin will not be loaded.";
+            qWarning() << "Plugin" << meta.fileName()
+                       << "is installed into the minuet plugin directory, but does not have"
+                          " \"Minuet/Plugin\" set as the service type. This plugin will not be loaded.";
             return false;
         }
         return true;
@@ -65,9 +65,10 @@ PluginController::~PluginController()
 
 bool PluginController::initialize(Core *core)
 {
+    m_errorString.clear();
 #if !defined(Q_OS_ANDROID)
-    foreach (const KPluginMetaData &pluginMetaData, m_plugins)
-    {
+    ISoundController *soundController = 0;
+    foreach (const KPluginMetaData &pluginMetaData, m_plugins) {
         if (m_loadedPlugins.value(pluginMetaData))
             continue;
 
@@ -75,22 +76,29 @@ bool PluginController::initialize(Core *core)
         IPlugin *plugin = qobject_cast<IPlugin *>(loader.instance());
         if (plugin) {
             m_loadedPlugins.insert(pluginMetaData, plugin);
-            ISoundController *soundController = 0;
             if (!core->soundController() && (soundController = qobject_cast<ISoundController *>(plugin))) {
-                qDebug() << "Setting soundcontroller to" << soundController->metaObject()->className();
+                qInfo() << "Setting soundcontroller to" << soundController->metaObject()->className();
                 core->setSoundController(soundController);
             }
         }
     }
+    if (!soundController) {
+        m_errorString = QStringLiteral("Could not find a suitable SoundController plugin!");
+        return false;
+    }
 #else
-        ISoundController *soundController = 0;
-        if (!core->soundController() && (soundController = new CsoundSoundController)) {
-            qDebug() << "Setting soundcontroller to" << soundController->metaObject()->className();
-            core->setSoundController(soundController);
-        }
+    ISoundController *soundController = 0;
+    if (!core->soundController() && (soundController = new CsoundSoundController)) {
+        qInfo() << "Setting soundcontroller to" << soundController->metaObject()->className();
+        core->setSoundController(soundController);
+    }
 #endif
     return true;
 }
 
+QString PluginController::errorString() const
+{
+    return m_errorString;
 }
 
+}
