@@ -32,7 +32,6 @@
 
 namespace Minuet
 {
-
 class Core;
 class IPlugin;
 
@@ -43,9 +42,9 @@ class PluginController : public IPluginController
 public:
     explicit PluginController(QObject *parent = 0);
     ~PluginController() override;
-    
+
     bool initialize(Core *core);
-    virtual QString errorString() const;
+    virtual QString errorString() const override;
 
 private:
 #ifndef Q_OS_ANDROID
