@@ -27,8 +27,8 @@
 
 #include <QObject>
 
-namespace Minuet {
-
+namespace Minuet
+{
 class MINUETINTERFACES_EXPORT IPlugin : public QObject
 {
     Q_OBJECT
